@@ -49,6 +49,7 @@ initialize = function(config){
   do_prework(config = config, verbosePackages = TRUE)
   imports = setdiff(config$order, config$plan$target)
   for(import in imports){ # Strict order needed. Might parallelize later.
+    config = inventory(config)
     hash_list = hash_list(targets = import, config = config)
     build(target = import, hash_list = hash_list, config = config)
   }
@@ -64,6 +65,7 @@ initialize = function(config){
 #' @param target name of target to make
 mk = function(target){
   config = get_cache()$get("config", namespace = "makefile")
+  config = inventory(config)
   do_prework(config = config, verbosePackages = FALSE)
   prune_envir(targets = target, config = config)
   hash_list = hash_list(targets = target, config = config)
@@ -73,8 +75,10 @@ mk = function(target){
   if(current) return(invisible())
   build(target = target, 
     hash_list = hash_list, config = config)
+  config = inventory(config)
   new_hash = self_hash(target = target, config = config)
-  if(!identical(old_hash, new_hash))
+  if(!identical(old_hash, new_hash)){
     file_overwrite(time_stamp(target))
+  }
   invisible()
 }
