@@ -3,9 +3,10 @@
 # numbers of jobs and mclapply vs Makefiles.
 
 testopts = function(){list(
-  jobs = 1, # needs to be 1 for mclapply on Windows
-  parallelism = "mclapply")
- # parallelism = "Makefile") # can't use for shipped unit tests
+  jobs = 2, # needs to be 1 for mclapply on Windows
+  parallelism = "parLapply") # use for shipped tests
+ # parallelism = "mclapply")
+ # parallelism = "Makefile")
 } # drake has to already be installed for the Makefile stuff
 
 testrun = function(config){
