@@ -12,6 +12,32 @@ test_that("prepend arg works", {
   dclean()
 })
 
+test_that("files inside directories can be timestamped", {
+  dclean()
+  plan = plan(list = c("'t1/t2'" = 
+    'dir.create("t1"); saveRDS(1, file.path("t1", "t2"))'))
+  plan$target[1] = file = eply::quotes(file.path("t1", "t2"), 
+    single = TRUE)
+  config = config(plan = plan, targets = plan$target[1],
+    parallelism = "parLapply", verbose = FALSE, packages = character(0),
+    prework = character(0), prepend = character(0),
+    command = character(0), args = character(0), envir = new.env(),
+    jobs = 1)
+  run_Makefile(config, run = FALSE)
+  expect_silent(mk(config$plan$target[1]))
+  expect_true(file.exists("t1"))
+  expect_true(file.exists(unquote(file)))
+  unlink("t1", recursive = TRUE)
+  expect_false(file.exists("t1"))
+  dclean()
+  expect_silent(make(config$plan, verbose = FALSE))
+  expect_true(file.exists("t1"))
+  expect_true(file.exists(unquote(file)))
+  unlink("t1", recursive = TRUE)
+  expect_false(file.exists("t1"))
+  dclean()
+})
+
 test_that("basic Makefile stuff works", {
   dclean()
   config = dbug()
@@ -20,9 +46,10 @@ test_that("basic Makefile stuff works", {
   config$verbose = FALSE
   run_Makefile(config, run = FALSE)
   expect_true(file.exists("Makefile"))
-  stamps = list.files(file.path(time_stamp_dir))
-  expect_equal(stamps, c("combined", "myinput", "nextone", 
-    "yourinput"))
+  stamps = sort(list.files(file.path(time_stamp_dir), full.names = TRUE))
+  stamps2 = sort(time_stamp(c("combined", "myinput", "nextone", 
+    "yourinput")))
+  expect_equal(stamps, stamps2)
   expect_false(file.exists("intermediatefile.rds"))
   mk("'intermediatefile.rds'")
   expect_true(file.exists("intermediatefile.rds"))
