@@ -1,6 +1,34 @@
 # library(testthat); library(devtools); load_all()
 context("other-features")
 
+test_that("tracked() works", {
+  dclean()
+  config = dbug()
+  x = tracked(plan = config$plan, envir = config$envir)
+  y = c("'intermediatefile.rds'", "yourinput", "nextone", "combined",
+    "myinput", "final", "j", "i", "h", "g", "f", "c", "b", "a", "saveRDS",
+    "'input.rds'", "readRDS")
+  expect_equal(x, y)
+  x = tracked(plan = config$plan, targets = "myinput", 
+    envir = config$envir)
+  y = c("myinput", "'input.rds'", "readRDS")
+  expect_equal(x, y)
+  dclean()
+})
+
+test_that("mclapply and lapply", {
+  dclean()
+  config = dbug()
+  make(plan = config$plan, envir = config$envir,
+    verbose = FALSE, jobs = 1, parallelism = "mclapply")  
+  expect_true(is.numeric(readd(final)))
+  clean()
+  make(plan = config$plan, envir = config$envir,
+    verbose = FALSE, jobs = 1, parallelism = "parLapply")
+  expect_true(is.numeric(readd(final)))
+  dclean()
+})
+
 test_that(".onLoad() warns correctly", {
   f = ".RData"
   expect_false(file.exists(f))
